#!/bin/bash

nodes=()

function main() {
    if [ "$#" -eq 4 ]
    then
	fill_nodes_array $1;
	shift;
    elif [ "$#" -eq 5 ] && [ "$1" == "-c" ]
    then
	fill_nodes_array $1 $2;
	shift 2;
    else
	echo "Use: $0 [-c] reservation_id nb_peer_hosts nb_tracker_hosts nb_proxy_hosts";
	exit 1;
    fi

    if [ $((1+$1+$2+$3)) -le ${#nodes[@]} ]
    then
	echo "registry.host = ${nodes[0]}" > eventcloud-hosts.properties;
	current_index=1;
	echo -n "peer.hosts =" >> eventcloud-hosts.properties;
	end_index_peers=$(($current_index+$1));
	while [[ $current_index -lt $end_index_peers ]]
	do
	    echo -n " ${nodes[$current_index]}" >> eventcloud-hosts.properties;
	    current_index=$(($current_index+1));
	done
	echo >> eventcloud-hosts.properties;
	echo -n "tracker.hosts =" >> eventcloud-hosts.properties;
	end_index_trackers=$(($current_index+$2));
	while [[ $current_index -lt $end_index_trackers ]]
	do
	    echo -n " ${nodes[$current_index]}" >> eventcloud-hosts.properties;
	    current_index=$(($current_index+1));
	done
        echo >> eventcloud-hosts.properties;
	echo -n "proxy.hosts =" >> eventcloud-hosts.properties;
	end_index_proxies=$(($current_index+$3));
	while [[ $current_index -lt $end_index_proxies ]]
	do
	    echo -n " ${nodes[$current_index]}" >> eventcloud-hosts.properties;
	    current_index=$(($current_index+1));
	done
    else
	echo "There is not enough nodes: only ${#nodes[@]} nodes are available and $((1+$1+$2+$3)) nodes (1 registry + $1 peers + $2 trackers + $3 proxies) are required";
    fi
}

function fill_nodes_array() {
    if ! type "oarstat" > /dev/null 2>&1
    then
        echo "The command oarstat is not installed, please run this script from a frontend";
        exit 1;
    elif [ "$#" -eq 1 ]
    then
	for node in $(oarstat -j $1 -f | grep assigned_hostnames | sed 's/assigned_hostnames//' |tr '+=' ' ')
	do
	    affect_nodes_array 1 $node;
	done
    else
	for node in $(oarstat -j $2 -f | grep assigned_hostnames | sed 's/assigned_hostnames//' |tr '+=' ' ')
	do
            [[ ${node:0:10} == "bordeplage" || ${node:0:10} == "sagittaire" ]] && affect_nodes_array 2 $node;
            [[ ${node:0:9} == "bordereau" || ${node:0:6} == "chicon" || ${node:0:8} == "graphene" || ${node:0:6} == "helios" || ${node:0:3} == "sol" || ${node:0:6} == "pastel" ]] && affect_nodes_array 4 $node;
            [[ ${node:0:10} == "borderline" || ${node:0:6} == "adonis" || ${node:0:4} == "edel" || ${node:0:6} == "genepi" || ${node:0:7} == "chimint" || ${node:0:10} == "chinqchint" || ${node:0:9} == "chirloute" || ${node:0:7} == "granduc" || ${node:0:7} == "griffon" || ${node:0:8} == "paradent" || ${node:0:8} == "parapide" || ${node:0:4} == "suno" ]] && affect_nodes_array 8 $node;
            [[ ${node:0:7} == "hercule" || ${node:0:5} == "orion" || ${node:0:6} == "taurus" ]] && affect_nodes_array 12 $host;
            [[ ${node:0:6} == "stremi" || ${node:0:9} == "parapluie" ]] && affect_nodes_array 24 $node;
	done
    fi
}

function affect_nodes_array() {
    i=0;
    while [[ $i -lt $1 ]]
    do
	nodes[${#nodes[@]}]=$2;
	i=$(($i+1));
    done
}

main $@
